@@ -1,6 +1,5 @@
-from powerbot_backtesting.data_acquisition import init_client, get_contract_ids, get_public_trades, \
-	get_public_trades_by_days, \
-	get_contract_history, get_signals, get_own_trades, get_internal_trades, get_own_orders
+from powerbot_backtesting.data_acquisition import init_client, get_contract_ids, get_public_trades, get_public_trades_by_days, \
+	get_contract_history, get_signals, get_own_trades, get_internal_trades, get_own_orders, get_contracts
 from powerbot_backtesting.data_analysis import flex_algo, pc_algo, flexpos_algo, generate_input_file, BacktestingAlgo
 from powerbot_backtesting.data_processing import get_orders, get_ohlc_data, get_orderbooks, calc_trade_vwap, \
 	calc_single_vwap, calc_rolling_vwap
