@@ -32,9 +32,13 @@ class BaseExporter(BaseModel, ABC):
     """
 
     @abstractmethod
-    def get_contract_ids(self, **kwargs) -> dict[str, list[str]]:
+    def get_contracts(self, **kwargs) -> list:
         """Acquire contracts from source as defined by specific exporter class."""
 
+    @abstractmethod
+    def get_contract_ids(self, **kwargs) -> dict[str, list[str]]:
+        """Acquire contract ids from source as defined by specific exporter class."""
+
     @abstractmethod
     def get_public_trades(self, **kwargs) -> dict[str, pd.DataFrame]:
         """Acquire public trades from source as defined by specific exporter class."""
@@ -309,6 +313,24 @@ class ApiExporter(BaseExporter):
 
         return values
 
+    @validate_arguments
+    def get_contracts(self,
+                      time_from: datetime = Field(description="Datetime in format yyyy-mm-dd hh:mm:ss", default_factory=type(None)),
+                      time_till: datetime = Field(description="Datetime in format yyyy-mm-dd hh:mm:ss", default_factory=type(None)),
+                      contract_ids: list[str] = None,
+                      contract_time: str = "all",
+                      products: list[str] = None,
+                      allow_udc: bool = False,
+                      delivery_areas: list[str] = None) -> list:
+        return pb.get_contracts(api_client=self.client,
+                                time_from=time_from,
+                                time_till=time_till,
+                                contract_ids=contract_ids,
+                                contract_time=contract_time,
+                                products=products,
+                                allow_udc=allow_udc,
+                                delivery_areas=delivery_areas)
+
     @validate_arguments
     def get_contract_ids(self,
                          time_from: datetime = Field(description="Datetime in format yyyy-mm-dd hh:mm:ss", default_factory=type(None)),
@@ -317,8 +339,7 @@ class ApiExporter(BaseExporter):
                          contract_time: str = "all",
                          products: list[str] = None,
                          allow_udc: bool = False,
-                         delivery_areas: list[str] = None,
-                         return_contract_objects: bool = False) -> Union[dict[str, list[str]], tuple[dict, dict]]:
+                         delivery_areas: list[str] = None) -> Union[dict[str, list[str]], tuple[dict, dict]]:
         """
         Loads all contract IDs for specified timeframe, either by hours, single day or multiple days. Alternatively, a list
         of contract IDs can be passed instead of a timeframe, returning a dictionary of contract IDs compatible with all other
@@ -352,8 +373,7 @@ class ApiExporter(BaseExporter):
                                    contract_time=contract_time,
                                    products=products,
                                    allow_udc=allow_udc,
-                                   delivery_areas=delivery_areas,
-                                   return_contract_objects=return_contract_objects)
+                                   delivery_areas=delivery_areas)
 
     @validate_arguments
     def get_public_trades(self,
@@ -672,6 +692,42 @@ class HistoryExporter(BaseExporter):
                                     skip_on_error=skip_on_error,
                                     keep_zip_files=keep_zip_files)
 
+    @validate_arguments
+    def get_contracts(self,
+                      time_from: datetime = Field(description="Datetime in format yyyy-mm-dd hh:mm:ss"),
+                      time_till: datetime = Field(description="Datetime in format yyyy-mm-dd hh:mm:ss"),
+                      contract_time: Optional[str] = "all",
+                      products: Optional[list[str]] = None,
+                      allow_udc: Optional[bool] = False) -> dict[str, list[str]]:
+        """
+        Loads all contract IDs for specified timeframe, either by hours, single day or multiple days from the local cache.
+        The cached data has to have been loaded via get_historic_data, since this function utilizes the contract file
+        as an index.
+
+        If time_from includes hh:mm:ss
+            loads data between both times in timesteps according to contract_time
+
+        If time_from doesn't include hh:mm:ss
+            loads data between both dates in timesteps according to contract_time
+
+        Args:
+            time_from (datetime): yyyy-mm-dd hh:mm:ss
+            time_till (datetime): yyyy-mm-dd hh:mm:ss
+            contract_time (str): all, hourly, half-hourly or quarter-hourly (all includes UDC)
+            products (list): Optional list of specific products to return
+            allow_udc (bool): True if user-defined contracts (block products) should also be returned on contract_time = all
+
+        Returns:
+            dict{key: (list[str])}: Dictionary of Contract IDs
+        """
+        return pb.get_historic_contract_ids(client=self.client,
+                                            time_from=time_from,
+                                            time_till=time_till,
+                                            contract_time=contract_time,
+                                            products=products if products else [],
+                                            allow_udc=allow_udc,
+                                            return_contract_objects=True)
+
     @validate_arguments
     def get_contract_ids(self,
                          time_from: datetime = Field(description="Datetime in format yyyy-mm-dd hh:mm:ss"),
