@@ -543,6 +543,8 @@ def _historic_data_transformation(files: list, exchange: str, filetype: str) ->
 						 "turnover": "total_quantity"},
 				inplace=True)
 
+			df = df.astype({"contract_id": "str"})
+
 			df["delta"] = [False if "snapshot" in i else True for i in df.details]
 			df.revision_no = [i for i in range(0, len(df))]
 			df.delivery_area = [NORDPOOL_EIC_CODES[i] for i in df.delivery_area.tolist()]
@@ -550,8 +552,8 @@ def _historic_data_transformation(files: list, exchange: str, filetype: str) ->
 			bids = [i["bids"] if "bids" in i else None for i in df.details.tolist()]
 
 			conversion = lambda i: [
-				{"order_id": v["orderId"], "price": v["price"], "quantity": v["quantity"],
-				 "contract_id": v["contractId"], "delivery_area": NORDPOOL_EIC_CODES[v["deliveryArea"]],
+				{"order_id": str(v["orderId"]), "price": float(v["price"]), "quantity": float(v["quantity"]),
+				 "contract_id": str(v["contractId"]), "delivery_area": NORDPOOL_EIC_CODES[v["deliveryArea"]],
 				 "order_entry_time": v["createdAt"]} for v in i]
 
 			df["asks"] = [conversion(i) if i else None for i in asks]
